@@ -51,6 +51,7 @@ SHARE_ID = '7cf7c200-d3af-4e05-b87e-9167c95dfcad'
 SHARE_ID2 = 'b51c5a31-aa5b-4254-9ee8-7d39fa4c8c38'
 SHARE_ID3 = '1379991d-037b-4897-bf3a-81b4aac72eff'
 SHARE_ID4 = '1cb41aad-fd9b-4964-8059-646f69de925e'
+SHARE_ID5 = '2cb41aad-fd9b-4964-8059-646f69de925f'
 SHARE_INSTANCE_ID = 'd24e7257-124e-4fb6-b05b-d384f660bc85'
 PARENT_SHARE_ID = '585c3935-2aa9-437c-8bad-5abae1076555'
 SNAPSHOT_ID = 'de4c9050-e2f9-4ce1-ade4-5ed0c9f26451'
@@ -68,6 +69,8 @@ AGGR_POOL_NAME = 'manila_aggr_1'
 FLEXGROUP_POOL_NAME = 'flexgroup_pool'
 ROOT_AGGREGATES = ('root_aggr_1', 'root_aggr_2')
 ROOT_VOLUME_AGGREGATE = 'manila1'
+SECURITY_CERT_DEFAULT_EXPIRE_DAYS = 365
+SECURITY_CERT_LARGE_EXPIRE_DAYS = 3652
 ROOT_VOLUME = 'root'
 CLUSTER_NODE = 'cluster1_01'
 CLUSTER_NODES = ('cluster1_01', 'cluster1_02')
@@ -574,14 +577,15 @@ SHARE_SERVER = {
     'network_allocations': (USER_NETWORK_ALLOCATIONS +
                             ADMIN_NETWORK_ALLOCATIONS),
     'host': SERVER_HOST,
-    'share_network_subnet': {
+    'share_network_subnets': [{
         'neutron_net_id': 'fake_neutron_net_id',
         'neutron_subnet_id': 'fake_neutron_subnet_id'
-    }
+    }]
 }
 
 SHARE_SERVER_2 = {
     'id': 'fake_id_2',
+    'source_share_server_id': 'fake_src_share_server_id_2',
     'share_network_id': 'c5b3a865-56d0-4d88-abe5-879965e099c9',
     'backend_details': {
         'vserver_name': VSERVER2
@@ -589,10 +593,10 @@ SHARE_SERVER_2 = {
     'network_allocations': (USER_NETWORK_ALLOCATIONS +
                             ADMIN_NETWORK_ALLOCATIONS),
     'host': SERVER_HOST_2,
-    'share_network_subnet': {
+    'share_network_subnets': [{
         'neutron_net_id': 'fake_neutron_net_id_2',
         'neutron_subnet_id': 'fake_neutron_subnet_id_2'
-    }
+    }]
 }
 
 VSERVER_INFO = {
@@ -954,6 +958,7 @@ FLEXGROUP_POOL = {
     'qos': True,
     'security_service_update_support': True,
     'netapp_flexgroup': True,
+    'netapp_cluster_name': 'fake_cluster_name',
 }
 
 FLEXGROUP_AGGR_SET = set(FLEXGROUP_POOL_OPT[FLEXGROUP_POOL_NAME])
@@ -1036,6 +1041,7 @@ POOLS = [
         'security_service_update_support': True,
         'share_server_multiple_subnet_support': True,
         'netapp_flexgroup': False,
+        'netapp_cluster_name': 'fake_cluster_name',
     },
     {
         'pool_name': AGGREGATES[1],
@@ -1064,6 +1070,7 @@ POOLS = [
         'security_service_update_support': True,
         'share_server_multiple_subnet_support': True,
         'netapp_flexgroup': False,
+        'netapp_cluster_name': 'fake_cluster_name',
     },
 ]
 
@@ -1072,6 +1079,7 @@ POOLS_VSERVER_CREDS = [
         'pool_name': AGGREGATES[0],
         'filter_function': None,
         'goodness_function': None,
+        'netapp_cluster_name': '',
         'netapp_aggregate': AGGREGATES[0],
         'total_capacity_gb': 'unknown',
         'free_capacity_gb': 1.1,
@@ -1783,7 +1791,7 @@ SHARE_NETWORK = {
     'name': 'fake_name',
     'description': 'fake_description',
     'security_services': [CIFS_SECURITY_SERVICE],
-    'subnets': [SHARE_NETWORK_SUBNET],
+    'share_network_subnets': [SHARE_NETWORK_SUBNET],
 }
 
 SHARE_TYPE_2 = copy.deepcopy(SHARE_TYPE)
